<template>
    <div class="device-info-container">
        <div class="content-container">
            <!-- <img :src="getImage('/device-overview/jmkt.png')" alt="" /> -->
            <img :src="instanceStore.current?.photoUrl" alt="" />
            <div class="device-info">
                <div class="status-row">
                    <span>
                        设备状态:
                        <j-badge
                            :status="
                                statusMap.get(
                                    instanceStore.current?.state?.value,
                                )
                            "
                        />
                        {{ instanceStore.current?.state?.text }}
                    </span>
                    <span>
                        运行状态:
                        <span class="normal">正常</span>
                    </span>

                </div>
                <h2>{{instanceStore.current?.name}}</h2>
                <div class="tag-box" v-if="instanceStore.detail.tags && instanceStore.detail.tags.length>0">
                    <span v-for="tag in instanceStore.detail.tags" :key="tag.id">{{tag.value}}</span>
                </div>
            </div>
        </div>
        <div class="content-desc">
            <div class="info-row">
                <span>设备ID：</span>
                <span>{{instanceStore.current?.id}}</span>
            </div>
            <div class="info-row">
                <span>产品名称：</span>
                <span>{{instanceStore.current?.productName}}</span>
            </div>
            <div class="info-row">
                <span>设备类型：</span>
                <span>{{instanceStore.current?.deviceType?.text}}</span>
            </div>
            <div class="info-row">
                <span>设备位置：</span>
                <span>{{instanceStore.detail?.location}}</span>
            </div>
            <div class="info-row">
                <span>设备型号：</span>
                <span>{{instanceStore.detail?.model}}</span>
            </div>
            <div class="info-row">
                <span>品牌：</span>
                <span>{{instanceStore.detail?.brand}}</span>
            </div>
            <div class="info-row">
                <span>出厂日期：</span>
                <span>{{instanceStore.detail?.manufactureDate}}</span>
            </div>            
            <div class="info-row">
                <span>负责人：</span>
                <span>{{instanceStore.detail?.custodian}}</span>
            </div>
            <div class="info-row">
                <span>联系电话：</span>
                <span>{{instanceStore.detail?.phone}}</span>
            </div>
            <div class="info-row">
                <span>创建时间：</span>
                <span>
                    {{instanceStore.current?.createTime
                ? moment(instanceStore.current?.createTime).format(
                        'YYYY-MM-DD HH:mm:ss',
                    )
                : ''}}</span>
            </div>

             <div class="info-row">
                <span>最后上线时间：</span>
                <span>
                    {{
                        instanceStore.current?.onlineTime
                            ? moment(instanceStore.current?.onlineTime).format(
                                    'YYYY-MM-DD HH:mm:ss',
                                )
                            : ''
                    }}
                    </span>
            </div>

        </div>
    </div>
</template>
<script lang="ts" name="DeviceInfo" setup>
import { getImage } from '@/utils/comm';
import { useInstanceStore } from '@/store/instance';
import moment from 'moment';

const instanceStore = useInstanceStore();

const statusMap = new Map();
statusMap.set('online', 'success');
statusMap.set('offline', 'error');
statusMap.set('notActive', 'warning');


onMounted(() => {});
</script>
<style scoped lang="less">
.device-info-container {
    flex: 1;
    display: flex;
    padding: 16px;
    height: 100%;
    background: white;
    .status-row {
        // border-bottom: 1px dotted #e6e6e6;
        display: flex;
        align-items: center;
        // justify-content: center;
        padding-bottom: 16px;
        > span {
            // flex: 1;
            display: inline-block;
            width: 180px;
            .normal {
                font-size: 16px;
                font-family: PingFang SC-Medium, PingFang SC;
                font-weight: 500;
                color: #4277ff;
                line-height: 22px;
            }
            .success {
                font-size: 16px;
                font-family: PingFang SC-Medium, PingFang SC;
                font-weight: 500;
                color: #15c646;
                line-height: 22px;
            }
        }
    }
    .content-container {
        flex: 1;
        padding: 10px 0;
        display: flex;
        align-items: flex-start;
        justify-content: space-around;
        border-right: 1px dotted #cecece;
        margin-right: 50px;
        > img {
            width: 157px;
            height: 204px;
            margin-right: 16px;
        }
        .device-info {
            // flex: 1;
            .tag-box {
                display: flex;
                align-items: center;
                margin-bottom: 16px;
                > span {
                    display: inline-block;
                    width: 63px;
                    height: 23px;
                    margin-right: 8px;
                    font-size: 14px;
                    font-family: PingFang SC-Regular, PingFang SC;
                    font-weight: 400;
                    color: #4277ff;
                    text-align: center;
                    line-height: 23px;
                    background: rgba(41, 136, 254, 0.12);
                    border-radius: 16px 16px 16px 16px;
                }
            }
        }
    }
    .content-desc {
        flex: 2;
        display: flex;
        flex-wrap: wrap;
        .info-row {
            width: 33%;
            > span:nth-child(1) {
                font-size: 14px;
                font-family: PingFang SC-Regular, PingFang SC;
                font-weight: 400;
                color: #828282;
                line-height: 26px;
            }
            > span:nth-child(2) {
                font-size: 14px;
                font-family: PingFang SC-Regular, PingFang SC;
                font-weight: 400;
                color: #4f4f4f;
                line-height: 26px;
            }
        }
    }
}
</style>
